componenttools.get_parent_and_start_stop_indices_of_components
==============================================================

.. autofunction:: abjad.tools.componenttools.get_parent_and_start_stop_indices_of_components.get_parent_and_start_stop_indices_of_components
